import { Manager } from '@kevisual/local-app-manager/manager';
import type { AssistantConfig } from '@/module/assistant/index.ts';
import { parseIfJson } from '@/module/assistant/index.ts';
import path from 'node:path';
import fs from 'node:fs';
import glob from 'fast-glob';
import type { App } from '@kevisual/router';
export class AssistantApp extends Manager {
  config: AssistantConfig;
  pagesPath: string;
  constructor(config: AssistantConfig, mainApp?: App) {
    config.checkMounted();
    const appsPath = config?.configPath?.appsDir || path.join(process.cwd(), 'apps');
    const pagesPath = config?.configPath?.pagesDir || path.join(process.cwd(), 'pages');
    const appsConfigPath = config.configPath?.appsConfigPath;
    const configFimename = path.basename(appsConfigPath || '');
    super({
      appsPath,
      configFilename: configFimename,
      mainApp: mainApp,
    });
    this.pagesPath = pagesPath;
    this.config = config;
  }
  pageList() {
    const pages = glob.sync('*/*/package.json', {
      cwd: this.pagesPath,
      onlyFiles: true,
    });
    const pagesParse = pages.map((page) => {
      const [user, app] = page.split('/');
      const contentStr = fs.readFileSync(path.join(this.pagesPath, page), 'utf-8');
      const content = parseIfJson(contentStr);
      return {
        user,
        app,
        version: content?.version,
        content,
      };
    });
    return pagesParse;
  }
}
