export type SyncConfigType = 'sync' | 'download' | 'upload' | 'none';
export type SyncConfig = {
  type?: SyncConfigType; // 是否可以同步
  url: string; // 文件具体的 url 的地址
};
export type SyncDirectory = {
  /**
   * 忽略的目录或则文件，默认忽略 node_modules 使用 fast-glob 去匹配,
   * 当同步文件夹的时候生效
   **/
  ignore?: string[];
  /**
   * 合并路径的源地址，https://kevisual.xiongxiao.me/root/ai/kevisual
   */
  registry?: string;
  files?: string[];
  replace?: Record<string, string>;
};
export interface Config {
  name?: string; // 项目名称
  version?: string; // 项目版本号
  registry?: string; // 项目仓库地址
  metadata?: Record<string, any>; // 元数据, 统一的配置
  syncDirectory?: SyncDirectory[];
  sync?: {
    [key: string]: SyncConfig | string;
  };
  checkDir?: {
    [key: string]: {
      url: string; // 需要检查的 url
      replace?: Record<string, string>; // 替换的路径
      ignore?: string[]; // 忽略的目录
      enabled?: boolean; // 是否启用
    };
  };
}

export type SyncList = {
  key?: string;
  filepath: string;
  exist?: boolean;
  hash?: string;
  /**
   * 是否需要鉴权, baseURL 为 kevisual 服务时，需要鉴权
   */
  auth?: boolean;
} & SyncConfig;
